@@ -13,20 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-
-
-from builtins import object
 from io import StringIO
 
-import six
-from future import standard_library
-from past.builtins import str
-from six import string_types as str
 from splunktaucclib.rest_handler.schema import RestSchema
 
-standard_library.install_aliases()
-
 __all__ = [
     "RestEntityBuilder",
     "RestEndpointBuilder",
@@ -35,7 +25,7 @@ __all__ = [
 ]
 
 
-class RestEntityBuilder(object):
+class RestEntityBuilder:
 
     _title_template = "[{}]"
     _rh_template = """
@@ -102,7 +92,7 @@ field.RestField(
         )
 
 
-class RestEndpointBuilder(object):
+class RestEndpointBuilder:
     def __init__(self, name, namespace, **kwargs):
         self._name = name
         self._namespace = namespace
@@ -188,7 +178,7 @@ def indent(lines, spaces=1):
     :param spaces: times of four
     :return:
     """
-    string_io = StringIO(six.text_type(lines))
+    string_io = StringIO(str(lines))
     indentation = spaces * 4
     prefix = " " * indentation
     lines = []
