@@ -15,15 +15,12 @@
 #
 
 
-
-from builtins import object
-
 from .base import indent, quote_string
 
 
-class RestFieldBuilder(object):
+class RestFieldBuilder:
 
-    _kv_template = '{name} = {value}'
+    _kv_template = "{name} = {value}"
     _rh_template = """field.RestField(
     {name},
     required={required},
@@ -39,7 +36,7 @@ class RestFieldBuilder(object):
     def generate_spec(self):
         return self._kv_template.format(
             name=self._field.name,
-            value='',
+            value="",
         )
 
     def _indent_validator(self):
