@@ -19,14 +19,11 @@ Global config schema.
 """
 
 
-
 import json
 import os
 import os.path as op
 import shutil
-from builtins import map, object
 
-from solnlib.utils import is_true
 from splunktaucclib.global_config import GlobalConfigSchema
 from splunktaucclib.rest_handler.endpoint.field import RestField
 
@@ -40,7 +37,6 @@ from .endpoint.multiple_model import (
     MultipleModelEndpointBuilder,
     MultipleModelEntityBuilder,
 )
-# model to get accesstoken for oauth
 from .endpoint.oauth_model import OAuthModelEndpointBuilder
 from .endpoint.single_model import (
     SingleModelEndpointBuilder,
@@ -48,9 +44,13 @@ from .endpoint.single_model import (
 )
 
 
+def _is_true(val):
+    return str(val).strip().upper() in ("1", "TRUE", "T", "Y", "YES")
+
+
 class GlobalConfigBuilderSchema(GlobalConfigSchema):
     def __init__(self, content, j2_env, *args, **kwargs):
-        super(GlobalConfigBuilderSchema, self).__init__(content, *args, **kwargs)
+        super().__init__(content, *args, **kwargs)
         self.j2_env = j2_env
         self._endpoints = {}
         self._parse_builder_schema()
@@ -154,12 +154,13 @@ class GlobalConfigBuilderSchema(GlobalConfigSchema):
     def _parse_field(self, content):
         field = RestField(
             content["field"],
-            required=is_true(content.get("required")),
-            encrypted=is_true(content.get("encrypted")),
+            required=_is_true(content.get("required")),
+            encrypted=_is_true(content.get("encrypted")),
             default=content.get("defaultValue"),
         )
         return RestFieldBuilder(
-            field, self._parse_validation(content.get("validators")),
+            field,
+            self._parse_validation(content.get("validators")),
         )
 
     def _parse_validation(self, validation):
@@ -204,7 +205,7 @@ class GlobalConfigBuilderSchema(GlobalConfigSchema):
         return content
 
 
-class GlobalConfigValidation(object):
+class GlobalConfigValidation:
 
     _validation_template = """validator.{validator}({arguments})"""
 
@@ -225,7 +226,8 @@ class GlobalConfigValidation(object):
             arguments = arguments or {}
             self._validators.append(
                 self._validation_template.format(
-                    validator=validator, arguments=self._arguments(**arguments),
+                    validator=validator,
+                    arguments=self._arguments(**arguments),
                 )
             )
 
@@ -241,7 +243,10 @@ class GlobalConfigValidation(object):
         if not kwargs:
             return ""
         args = list(
-            map(lambda k_v: "{}={}, ".format(k_v[0], k_v[1]), list(kwargs.items()),)
+            map(
+                lambda k_v: "{}={}, ".format(k_v[0], k_v[1]),
+                list(kwargs.items()),
+            )
         )
         args.insert(0, "")
         args.append("")
@@ -309,7 +314,9 @@ class GlobalConfigValidation(object):
     def multiple_validators(cls, validators):
         validators_str = ", \n".join(validators)
         _template = """validator.AllOf(\n{validators}\n)"""
-        return _template.format(validators=indent(validators_str),)
+        return _template.format(
+            validators=indent(validators_str),
+        )
 
 
 GlobalConfigValidation.validation_mapping = {
@@ -323,7 +330,7 @@ GlobalConfigValidation.validation_mapping = {
 }
 
 
-class GlobalConfigPostProcessor(object):
+class GlobalConfigPostProcessor:
     """
     Post process for REST builder.
     """
@@ -360,8 +367,14 @@ sys.path = new_paths
         return self.schema.namespace
 
     def default_to_local(self):
-        default_dir = op.join(self.root_path, self.builder.output.default,)
-        local_dir = op.join(self.root_path, self.output_local,)
+        default_dir = op.join(
+            self.root_path,
+            self.builder.output.default,
+        )
+        local_dir = op.join(
+            self.root_path,
+            self.output_local,
+        )
         if not op.isdir(local_dir):
             os.makedirs(local_dir)
         for i in os.listdir(default_dir):
@@ -385,7 +398,9 @@ sys.path = new_paths
             self.builder.output.bin,
             self.import_declare_py_name() + ".py",
         )
-        content = self._import_declare_content.format(ta_name=self.schema.product,)
+        content = self._import_declare_content.format(
+            ta_name=self.schema.product,
+        )
         with open(import_declare_file, "w") as f:
             f.write(content)
 
